@@ -1,5 +1,3 @@
-package org.eclipse.aether.repository;
-
 /*
  * Licensed to the Apache Software Foundation (ASF) under one
  * or more contributor license agreements.  See the NOTICE file
@@ -8,9 +6,9 @@ package org.eclipse.aether.repository;
  * to you under the Apache License, Version 2.0 (the
  * "License"); you may not use this file except in compliance
  * with the License.  You may obtain a copy of the License at
- * 
- *  http://www.apache.org/licenses/LICENSE-2.0
- * 
+ *
+ *   http://www.apache.org/licenses/LICENSE-2.0
+ *
  * Unless required by applicable law or agreed to in writing,
  * software distributed under the License is distributed on an
  * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
@@ -18,23 +16,25 @@ package org.eclipse.aether.repository;
  * specific language governing permissions and limitations
  * under the License.
  */
+package org.eclipse.aether.repository;
 
 import java.io.Closeable;
 import java.io.File;
 import java.util.Arrays;
 import java.util.HashMap;
 import java.util.Map;
-import static java.util.Objects.requireNonNull;
 
 import org.eclipse.aether.RepositorySystemSession;
 
+import static java.util.Objects.requireNonNull;
+
 /**
  * A glorified map of key value pairs holding (cleartext) authentication data. Authentication contexts are used
  * internally when network operations need to access secured repositories or proxies. Each authentication context
  * manages the credentials required to access a single host. Unlike {@link Authentication} callbacks which exist for a
  * potentially long time like the duration of a repository system session, an authentication context has a supposedly
  * short lifetime and should be {@link #close() closed} as soon as the corresponding network operation has finished:
- * 
+ *
  * <pre>
  * AuthenticationContext context = AuthenticationContext.forRepository( session, repository );
  * try {
@@ -47,7 +47,7 @@ import org.eclipse.aether.RepositorySystemSession;
  *     AuthenticationContext.close( context );
  * }
  * </pre>
- * 
+ *
  * The same authentication data can often be presented using different data types, e.g. a password can be presented
  * using a character array or (less securely) using a string. For ease of use, an authentication context treats the
  * following groups of data types as equivalent and converts values automatically during retrieval:
@@ -57,9 +57,7 @@ import org.eclipse.aether.RepositorySystemSession;
  * </ul>
  * An authentication context is thread-safe.
  */
-public final class AuthenticationContext
-    implements Closeable
-{
+public final class AuthenticationContext implements Closeable {
 
     /**
      * The key used to store the username. The corresponding authentication data should be of type {@link String}.
@@ -143,44 +141,39 @@ public final class AuthenticationContext
 
     /**
      * Gets an authentication context for the specified repository.
-     * 
+     *
      * @param session The repository system session during which the repository is accessed, must not be {@code null}.
      * @param repository The repository for which to create an authentication context, must not be {@code null}.
      * @return An authentication context for the repository or {@code null} if no authentication is configured for it.
      */
-    public static AuthenticationContext forRepository( RepositorySystemSession session, RemoteRepository repository )
-    {
-        return newInstance( session, repository, null, repository.getAuthentication() );
+    public static AuthenticationContext forRepository(RepositorySystemSession session, RemoteRepository repository) {
+        return newInstance(session, repository, null, repository.getAuthentication());
     }
 
     /**
      * Gets an authentication context for the proxy of the specified repository.
-     * 
+     *
      * @param session The repository system session during which the repository is accessed, must not be {@code null}.
      * @param repository The repository for whose proxy to create an authentication context, must not be {@code null}.
      * @return An authentication context for the proxy or {@code null} if no proxy is set or no authentication is
      *         configured for it.
      */
-    public static AuthenticationContext forProxy( RepositorySystemSession session, RemoteRepository repository )
-    {
+    public static AuthenticationContext forProxy(RepositorySystemSession session, RemoteRepository repository) {
         Proxy proxy = repository.getProxy();
-        return newInstance( session, repository, proxy, ( proxy != null ) ? proxy.getAuthentication() : null );
+        return newInstance(session, repository, proxy, (proxy != null) ? proxy.getAuthentication() : null);
     }
 
-    private static AuthenticationContext newInstance( RepositorySystemSession session, RemoteRepository repository,
-                                                      Proxy proxy, Authentication auth )
-    {
-        if ( auth == null )
-        {
+    private static AuthenticationContext newInstance(
+            RepositorySystemSession session, RemoteRepository repository, Proxy proxy, Authentication auth) {
+        if (auth == null) {
             return null;
         }
-        return new AuthenticationContext( session, repository, proxy, auth );
+        return new AuthenticationContext(session, repository, proxy, auth);
     }
 
-    private AuthenticationContext( RepositorySystemSession session, RemoteRepository repository, Proxy proxy,
-                                   Authentication auth )
-    {
-        this.session = requireNonNull( session, "repository system session cannot be null" );
+    private AuthenticationContext(
+            RepositorySystemSession session, RemoteRepository repository, Proxy proxy, Authentication auth) {
+        this.session = requireNonNull(session, "repository system session cannot be null");
         this.repository = repository;
         this.proxy = proxy;
         this.auth = auth;
@@ -189,62 +182,57 @@ public final class AuthenticationContext
 
     /**
      * Gets the repository system session during which the authentication happens.
-     * 
+     *
      * @return The repository system session, never {@code null}.
      */
-    public RepositorySystemSession getSession()
-    {
+    public RepositorySystemSession getSession() {
         return session;
     }
 
     /**
      * Gets the repository requiring authentication. If {@link #getProxy()} is not {@code null}, the data gathered by
      * this authentication context does not apply to the repository's host but rather the proxy.
-     * 
+     *
      * @return The repository to be contacted, never {@code null}.
      */
-    public RemoteRepository getRepository()
-    {
+    public RemoteRepository getRepository() {
         return repository;
     }
 
     /**
      * Gets the proxy (if any) to be authenticated with.
-     * 
+     *
      * @return The proxy or {@code null} if authenticating directly with the repository's host.
      */
-    public Proxy getProxy()
-    {
+    public Proxy getProxy() {
         return proxy;
     }
 
     /**
      * Gets the authentication data for the specified key.
-     * 
+     *
      * @param key The key whose authentication data should be retrieved, must not be {@code null}.
      * @return The requested authentication data or {@code null} if none.
      */
-    public String get( String key )
-    {
-        return get( key, null, String.class );
+    public String get(String key) {
+        return get(key, null, String.class);
     }
 
     /**
      * Gets the authentication data for the specified key.
-     * 
+     *
      * @param <T> The data type of the authentication data.
      * @param key The key whose authentication data should be retrieved, must not be {@code null}.
      * @param type The expected type of the authentication data, must not be {@code null}.
      * @return The requested authentication data or {@code null} if none or if the data doesn't match the expected type.
      */
-    public <T> T get( String key, Class<T> type )
-    {
-        return get( key, null, type );
+    public <T> T get(String key, Class<T> type) {
+        return get(key, null, type);
     }
 
     /**
      * Gets the authentication data for the specified key.
-     * 
+     *
      * @param <T> The data type of the authentication data.
      * @param key The key whose authentication data should be retrieved, must not be {@code null}.
      * @param data Any (read-only) extra data in form of key value pairs that might be useful when getting the
@@ -252,77 +240,55 @@ public final class AuthenticationContext
      * @param type The expected type of the authentication data, must not be {@code null}.
      * @return The requested authentication data or {@code null} if none or if the data doesn't match the expected type.
      */
-    public <T> T get( String key, Map<String, String> data, Class<T> type )
-    {
-        requireNonNull( key, "authentication key cannot be null" );
-        if ( key.length() == 0 )
-        {
-            throw new IllegalArgumentException( "authentication key cannot be empty" );
+    public <T> T get(String key, Map<String, String> data, Class<T> type) {
+        requireNonNull(key, "authentication key cannot be null");
+        if (key.length() == 0) {
+            throw new IllegalArgumentException("authentication key cannot be empty");
         }
 
         Object value;
-        synchronized ( authData )
-        {
-            value = authData.get( key );
-            if ( value == null && !authData.containsKey( key ) && !fillingAuthData )
-            {
-                if ( auth != null )
-                {
-                    try
-                    {
+        synchronized (authData) {
+            value = authData.get(key);
+            if (value == null && !authData.containsKey(key) && !fillingAuthData) {
+                if (auth != null) {
+                    try {
                         fillingAuthData = true;
-                        auth.fill( this, key, data );
-                    }
-                    finally
-                    {
+                        auth.fill(this, key, data);
+                    } finally {
                         fillingAuthData = false;
                     }
-                    value = authData.get( key );
+                    value = authData.get(key);
                 }
-                if ( value == null )
-                {
-                    authData.put( key, value );
+                if (value == null) {
+                    authData.put(key, null);
                 }
             }
         }
 
-        return convert( value, type );
+        return convert(value, type);
     }
 
-    private <T> T convert( Object value, Class<T> type )
-    {
-        if ( !type.isInstance( value ) )
-        {
-            if ( String.class.equals( type ) )
-            {
-                if ( value instanceof File )
-                {
-                    value = ( (File) value ).getPath();
+    private <T> T convert(Object value, Class<T> type) {
+        if (!type.isInstance(value)) {
+            if (String.class.equals(type)) {
+                if (value instanceof File) {
+                    value = ((File) value).getPath();
+                } else if (value instanceof char[]) {
+                    value = new String((char[]) value);
                 }
-                else if ( value instanceof char[] )
-                {
-                    value = new String( (char[]) value );
+            } else if (File.class.equals(type)) {
+                if (value instanceof String) {
+                    value = new File((String) value);
                 }
-            }
-            else if ( File.class.equals( type ) )
-            {
-                if ( value instanceof String )
-                {
-                    value = new File( (String) value );
-                }
-            }
-            else if ( char[].class.equals( type ) )
-            {
-                if ( value instanceof String )
-                {
-                    value = ( (String) value ).toCharArray();
+            } else if (char[].class.equals(type)) {
+                if (value instanceof String) {
+                    value = ((String) value).toCharArray();
                 }
             }
         }
 
-        if ( type.isInstance( value ) )
-        {
-            return type.cast( value );
+        if (type.isInstance(value)) {
+            return type.cast(value);
         }
 
         return null;
@@ -336,20 +302,16 @@ public final class AuthenticationContext
      * @param key The key to associate the authentication data with, must not be {@code null}.
      * @param value The (cleartext) authentication data to store, may be {@code null}.
      */
-    public void put( String key, Object value )
-    {
-        requireNonNull( key, "authentication key cannot be null" );
-        if ( key.length() == 0 )
-        {
-            throw new IllegalArgumentException( "authentication key cannot be empty" );
+    public void put(String key, Object value) {
+        requireNonNull(key, "authentication key cannot be null");
+        if (key.length() == 0) {
+            throw new IllegalArgumentException("authentication key cannot be empty");
         }
 
-        synchronized ( authData )
-        {
-            Object oldValue = authData.put( key, value );
-            if ( oldValue instanceof char[] )
-            {
-                Arrays.fill( (char[]) oldValue, '\0' );
+        synchronized (authData) {
+            Object oldValue = authData.put(key, value);
+            if (oldValue instanceof char[]) {
+                Arrays.fill((char[]) oldValue, '\0');
             }
         }
     }
@@ -358,15 +320,11 @@ public final class AuthenticationContext
      * Closes this authentication context and erases sensitive authentication data from heap memory. Closing an already
      * closed context has no effect.
      */
-    public void close()
-    {
-        synchronized ( authData )
-        {
-            for ( Object value : authData.values() )
-            {
-                if ( value instanceof char[] )
-                {
-                    Arrays.fill( (char[]) value, '\0' );
+    public void close() {
+        synchronized (authData) {
+            for (Object value : authData.values()) {
+                if (value instanceof char[]) {
+                    Arrays.fill((char[]) value, '\0');
                 }
             }
             authData.clear();
@@ -376,15 +334,12 @@ public final class AuthenticationContext
     /**
      * Closes the specified authentication context. This is a convenience method doing a {@code null} check before
      * calling {@link #close()} on the given context.
-     * 
+     *
      * @param context The authentication context to close, may be {@code null}.
      */
-    public static void close( AuthenticationContext context )
-    {
-        if ( context != null )
-        {
+    public static void close(AuthenticationContext context) {
+        if (context != null) {
             context.close();
         }
     }
-
 }
