@@ -1,5 +1,3 @@
-package org.eclipse.aether.resolution;
-
 /*
  * Licensed to the Apache Software Foundation (ASF) under one
  * or more contributor license agreements.  See the NOTICE file
@@ -8,9 +6,9 @@ package org.eclipse.aether.resolution;
  * to you under the Apache License, Version 2.0 (the
  * "License"); you may not use this file except in compliance
  * with the License.  You may obtain a copy of the License at
- * 
- *  http://www.apache.org/licenses/LICENSE-2.0
- * 
+ *
+ *   http://www.apache.org/licenses/LICENSE-2.0
+ *
  * Unless required by applicable law or agreed to in writing,
  * software distributed under the License is distributed on an
  * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
@@ -18,6 +16,7 @@ package org.eclipse.aether.resolution;
  * specific language governing permissions and limitations
  * under the License.
  */
+package org.eclipse.aether.resolution;
 
 import java.util.ArrayList;
 import java.util.Collections;
@@ -30,11 +29,10 @@ import org.eclipse.aether.repository.RemoteRepository;
 
 /**
  * A request to resolve a metaversion.
- * 
+ *
  * @see RepositorySystem#resolveVersion(org.eclipse.aether.RepositorySystemSession, VersionRequest)
  */
-public final class VersionRequest
-{
+public final class VersionRequest {
 
     private Artifact artifact;
 
@@ -47,71 +45,62 @@ public final class VersionRequest
     /**
      * Creates an uninitialized request.
      */
-    public VersionRequest()
-    {
+    public VersionRequest() {
         // enables default constructor
     }
 
     /**
      * Creates a request with the specified properties.
-     * 
+     *
      * @param artifact The artifact whose (meta-)version should be resolved, may be {@code null}.
      * @param repositories The repositories to resolve the version from, may be {@code null}.
      * @param context The context in which this request is made, may be {@code null}.
      */
-    public VersionRequest( Artifact artifact, List<RemoteRepository> repositories, String context )
-    {
-        setArtifact( artifact );
-        setRepositories( repositories );
-        setRequestContext( context );
+    public VersionRequest(Artifact artifact, List<RemoteRepository> repositories, String context) {
+        setArtifact(artifact);
+        setRepositories(repositories);
+        setRequestContext(context);
     }
 
     /**
      * Gets the artifact whose (meta-)version shall be resolved.
-     * 
+     *
      * @return The artifact or {@code null} if not set.
      */
-    public Artifact getArtifact()
-    {
+    public Artifact getArtifact() {
         return artifact;
     }
 
     /**
      * Sets the artifact whose (meta-)version shall be resolved.
-     * 
+     *
      * @param artifact The artifact, may be {@code null}.
      * @return This request for chaining, never {@code null}.
      */
-    public VersionRequest setArtifact( Artifact artifact )
-    {
+    public VersionRequest setArtifact(Artifact artifact) {
         this.artifact = artifact;
         return this;
     }
 
     /**
      * Gets the repositories to resolve the version from.
-     * 
+     *
      * @return The repositories, never {@code null}.
      */
-    public List<RemoteRepository> getRepositories()
-    {
+    public List<RemoteRepository> getRepositories() {
         return repositories;
     }
 
     /**
      * Sets the repositories to resolve the version from.
-     * 
+     *
      * @param repositories The repositories, may be {@code null}.
      * @return This request for chaining, never {@code null}.
      */
-    public VersionRequest setRepositories( List<RemoteRepository> repositories )
-    {
-        if ( repositories == null )
-        {
+    public VersionRequest setRepositories(List<RemoteRepository> repositories) {
+        if (repositories == null) {
             this.repositories = Collections.emptyList();
-        }
-        else
-        {
+        } else {
             this.repositories = repositories;
         }
         return this;
@@ -119,71 +108,62 @@ public final class VersionRequest
 
     /**
      * Adds the specified repository for the resolution.
-     * 
+     *
      * @param repository The repository to add, may be {@code null}.
      * @return This request for chaining, never {@code null}.
      */
-    public VersionRequest addRepository( RemoteRepository repository )
-    {
-        if ( repository != null )
-        {
-            if ( this.repositories.isEmpty() )
-            {
+    public VersionRequest addRepository(RemoteRepository repository) {
+        if (repository != null) {
+            if (this.repositories.isEmpty()) {
                 this.repositories = new ArrayList<>();
             }
-            this.repositories.add( repository );
+            this.repositories.add(repository);
         }
         return this;
     }
 
     /**
      * Gets the context in which this request is made.
-     * 
+     *
      * @return The context, never {@code null}.
      */
-    public String getRequestContext()
-    {
+    public String getRequestContext() {
         return context;
     }
 
     /**
      * Sets the context in which this request is made.
-     * 
+     *
      * @param context The context, may be {@code null}.
      * @return This request for chaining, never {@code null}.
      */
-    public VersionRequest setRequestContext( String context )
-    {
-        this.context = ( context != null ) ? context : "";
+    public VersionRequest setRequestContext(String context) {
+        this.context = (context != null) ? context : "";
         return this;
     }
 
     /**
      * Gets the trace information that describes the higher level request/operation in which this request is issued.
-     * 
+     *
      * @return The trace information about the higher level operation or {@code null} if none.
      */
-    public RequestTrace getTrace()
-    {
+    public RequestTrace getTrace() {
         return trace;
     }
 
     /**
      * Sets the trace information that describes the higher level request/operation in which this request is issued.
-     * 
+     *
      * @param trace The trace information about the higher level operation, may be {@code null}.
      * @return This request for chaining, never {@code null}.
      */
-    public VersionRequest setTrace( RequestTrace trace )
-    {
+    public VersionRequest setTrace(RequestTrace trace) {
         this.trace = trace;
         return this;
     }
 
     @Override
-    public String toString()
-    {
+    public String toString() {
         return getArtifact() + " < " + getRepositories();
     }
-
 }
