@@ -1,5 +1,3 @@
-package org.eclipse.aether.transfer;
-
 /*
  * Licensed to the Apache Software Foundation (ASF) under one
  * or more contributor license agreements.  See the NOTICE file
@@ -8,9 +6,9 @@ package org.eclipse.aether.transfer;
  * to you under the Apache License, Version 2.0 (the
  * "License"); you may not use this file except in compliance
  * with the License.  You may obtain a copy of the License at
- * 
- *  http://www.apache.org/licenses/LICENSE-2.0
- * 
+ *
+ *   http://www.apache.org/licenses/LICENSE-2.0
+ *
  * Unless required by applicable law or agreed to in writing,
  * software distributed under the License is distributed on an
  * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
@@ -18,26 +16,26 @@ package org.eclipse.aether.transfer;
  * specific language governing permissions and limitations
  * under the License.
  */
+package org.eclipse.aether.transfer;
 
 import java.nio.ByteBuffer;
-import static java.util.Objects.requireNonNull;
 
 import org.eclipse.aether.RepositorySystemSession;
 
+import static java.util.Objects.requireNonNull;
+
 /**
  * An event fired to a transfer listener during an artifact/metadata transfer.
  *
  * @see TransferListener
  * @see TransferEvent.Builder
  */
-public final class TransferEvent
-{
+public final class TransferEvent {
 
     /**
      * The type of the event.
      */
-    public enum EventType
-    {
+    public enum EventType {
 
         /**
          * @see TransferListener#transferInitiated(TransferEvent)
@@ -68,14 +66,12 @@ public final class TransferEvent
          * @see TransferListener#transferFailed(TransferEvent)
          */
         FAILED
-
     }
 
     /**
      * The type of the request/transfer being performed.
      */
-    public enum RequestType
-    {
+    public enum RequestType {
 
         /**
          * Download artifact/metadata.
@@ -91,7 +87,6 @@ public final class TransferEvent
          * Upload artifact/metadata.
          */
         PUT,
-
     }
 
     private final EventType type;
@@ -108,8 +103,7 @@ public final class TransferEvent
 
     private final Exception exception;
 
-    TransferEvent( Builder builder )
-    {
+    TransferEvent(Builder builder) {
         type = builder.type;
         requestType = builder.requestType;
         session = builder.session;
@@ -121,41 +115,37 @@ public final class TransferEvent
 
     /**
      * Gets the type of the event.
-     * 
+     *
      * @return The type of the event, never {@code null}.
      */
-    public EventType getType()
-    {
+    public EventType getType() {
         return type;
     }
 
     /**
      * Gets the type of the request/transfer.
-     * 
+     *
      * @return The type of the request/transfer, never {@code null}.
      */
-    public RequestType getRequestType()
-    {
+    public RequestType getRequestType() {
         return requestType;
     }
 
     /**
      * Gets the repository system session during which the event occurred.
-     * 
+     *
      * @return The repository system session during which the event occurred, never {@code null}.
      */
-    public RepositorySystemSession getSession()
-    {
+    public RepositorySystemSession getSession() {
         return session;
     }
 
     /**
      * Gets the resource that is being transferred.
-     * 
+     *
      * @return The resource being transferred, never {@code null}.
      */
-    public TransferResource getResource()
-    {
+    public TransferResource getResource() {
         return resource;
     }
 
@@ -164,13 +154,12 @@ public final class TransferEvent
      * If a download has been resumed, the returned count includes the bytes that were already downloaded during the
      * previous attempt. In other words, the ratio of transferred bytes to the content length of the resource indicates
      * the percentage of transfer completion.
-     * 
+     *
      * @return The total number of bytes that have been transferred since the transfer started, never negative.
      * @see #getDataLength()
      * @see TransferResource#getResumeOffset()
      */
-    public long getTransferredBytes()
-    {
+    public long getTransferredBytes() {
         return transferredBytes;
     }
 
@@ -180,55 +169,50 @@ public final class TransferEvent
      * duration of the event callback, i.e. the next event might reuse the same buffer (with updated contents).
      * Therefore, if the actual event processing is deferred, the byte buffer would have to be cloned to create an
      * immutable snapshot of its contents.
-     * 
+     *
      * @return The (read-only) byte buffer or {@code null} if not applicable to the event, i.e. if the event type is not
      *         {@link EventType#PROGRESSED}.
      */
-    public ByteBuffer getDataBuffer()
-    {
-        return ( dataBuffer != null ) ? dataBuffer.asReadOnlyBuffer() : null;
+    public ByteBuffer getDataBuffer() {
+        return (dataBuffer != null) ? dataBuffer.asReadOnlyBuffer() : null;
     }
 
     /**
      * Gets the number of bytes that have been transferred since the last event.
-     * 
+     *
      * @return The number of bytes that have been transferred since the last event, possibly zero but never negative.
      * @see #getTransferredBytes()
      */
-    public int getDataLength()
-    {
-        return ( dataBuffer != null ) ? dataBuffer.remaining() : 0;
+    public int getDataLength() {
+        return (dataBuffer != null) ? dataBuffer.remaining() : 0;
     }
 
     /**
      * Gets the error that occurred during the transfer.
-     * 
+     *
      * @return The error that occurred or {@code null} if none.
      */
-    public Exception getException()
-    {
+    public Exception getException() {
         return exception;
     }
 
     @Override
-    public String toString()
-    {
+    public String toString() {
         return getRequestType() + " " + getType() + " " + getResource();
     }
 
     /**
      * A builder to create transfer events.
      */
-    public static final class Builder
-    {
+    public static final class Builder {
 
         EventType type;
 
         RequestType requestType;
 
-        RepositorySystemSession session;
+        final RepositorySystemSession session;
 
-        TransferResource resource;
+        final TransferResource resource;
 
         ByteBuffer dataBuffer;
 
@@ -242,16 +226,14 @@ public final class TransferEvent
          * @param session The repository system session, must not be {@code null}.
          * @param resource The resource being transferred, must not be {@code null}.
          */
-        public Builder( RepositorySystemSession session, TransferResource resource )
-        {
-            this.session = requireNonNull( session, "repository system session cannot be null" );
-            this.resource = requireNonNull( resource, "transfer resource cannot be null" );
+        public Builder(RepositorySystemSession session, TransferResource resource) {
+            this.session = requireNonNull(session, "repository system session cannot be null");
+            this.resource = requireNonNull(resource, "transfer resource cannot be null");
             type = EventType.INITIATED;
             requestType = RequestType.GET;
         }
 
-        private Builder( Builder prototype )
-        {
+        private Builder(Builder prototype) {
             session = prototype.session;
             resource = prototype.resource;
             type = prototype.type;
@@ -264,12 +246,11 @@ public final class TransferEvent
         /**
          * Creates a new transfer event builder from the current values of this builder. The state of this builder
          * remains unchanged.
-         * 
+         *
          * @return The new event builder, never {@code null}.
          */
-        public Builder copy()
-        {
-            return new Builder( this );
+        public Builder copy() {
+            return new Builder(this);
         }
 
         /**
@@ -280,13 +261,11 @@ public final class TransferEvent
          * @param type The type of the event, must not be {@code null}.
          * @return This event builder for chaining, never {@code null}.
          */
-        public Builder resetType( EventType type )
-        {
-            this.type = requireNonNull( type, "event type cannot be null" );
+        public Builder resetType(EventType type) {
+            this.type = requireNonNull(type, "event type cannot be null");
             dataBuffer = null;
             exception = null;
-            switch ( type )
-            {
+            switch (type) {
                 case INITIATED:
                 case STARTED:
                     transferredBytes = 0L;
@@ -302,9 +281,8 @@ public final class TransferEvent
          * @param type The type of the event, must not be {@code null}.
          * @return This event builder for chaining, never {@code null}.
          */
-        public Builder setType( EventType type )
-        {
-            this.type = requireNonNull( type, "event type cannot be null" );
+        public Builder setType(EventType type) {
+            this.type = requireNonNull(type, "event type cannot be null");
             return this;
         }
 
@@ -314,9 +292,8 @@ public final class TransferEvent
          * @param requestType The request/transfer type, must not be {@code null}.
          * @return This event builder for chaining, never {@code null}.
          */
-        public Builder setRequestType( RequestType requestType )
-        {
-            this.requestType = requireNonNull( requestType, "request type cannot be null" );
+        public Builder setRequestType(RequestType requestType) {
+            this.requestType = requireNonNull(requestType, "request type cannot be null");
             return this;
         }
 
@@ -325,17 +302,15 @@ public final class TransferEvent
          * If a download is being resumed, the count must include the bytes that were already downloaded in the previous
          * attempt and from which the current transfer started. In this case, the event type {@link EventType#STARTED}
          * should indicate from what byte the download resumes.
-         * 
+         *
          * @param transferredBytes The total number of bytes that have been transferred so far during the
          *            download/upload of the resource, must not be negative.
          * @return This event builder for chaining, never {@code null}.
          * @see TransferResource#setResumeOffset(long)
          */
-        public Builder setTransferredBytes( long transferredBytes )
-        {
-            if ( transferredBytes < 0L )
-            {
-                throw new IllegalArgumentException( "number of transferred bytes cannot be negative" );
+        public Builder setTransferredBytes(long transferredBytes) {
+            if (transferredBytes < 0L) {
+                throw new IllegalArgumentException("number of transferred bytes cannot be negative");
             }
             this.transferredBytes = transferredBytes;
             return this;
@@ -348,11 +323,9 @@ public final class TransferEvent
          *            negative.
          * @return This event builder for chaining, never {@code null}.
          */
-        public Builder addTransferredBytes( long transferredBytes )
-        {
-            if ( transferredBytes < 0L )
-            {
-                throw new IllegalArgumentException( "number of transferred bytes cannot be negative" );
+        public Builder addTransferredBytes(long transferredBytes) {
+            if (transferredBytes < 0L) {
+                throw new IllegalArgumentException("number of transferred bytes cannot be negative");
             }
             this.transferredBytes += transferredBytes;
             return this;
@@ -360,39 +333,36 @@ public final class TransferEvent
 
         /**
          * Sets the byte buffer holding the transferred bytes since the last event.
-         * 
+         *
          * @param buffer The byte buffer holding the transferred bytes since the last event, may be {@code null} if not
          *            applicable to the event.
          * @param offset The starting point of valid bytes in the array.
          * @param length The number of valid bytes, must not be negative.
          * @return This event builder for chaining, never {@code null}.
          */
-        public Builder setDataBuffer( byte[] buffer, int offset, int length )
-        {
-            return setDataBuffer( ( buffer != null ) ? ByteBuffer.wrap( buffer, offset, length ) : null );
+        public Builder setDataBuffer(byte[] buffer, int offset, int length) {
+            return setDataBuffer((buffer != null) ? ByteBuffer.wrap(buffer, offset, length) : null);
         }
 
         /**
          * Sets the byte buffer holding the transferred bytes since the last event.
-         * 
+         *
          * @param dataBuffer The byte buffer holding the transferred bytes since the last event, may be {@code null} if
          *            not applicable to the event.
          * @return This event builder for chaining, never {@code null}.
          */
-        public Builder setDataBuffer( ByteBuffer dataBuffer )
-        {
+        public Builder setDataBuffer(ByteBuffer dataBuffer) {
             this.dataBuffer = dataBuffer;
             return this;
         }
 
         /**
          * Sets the error that occurred during the transfer.
-         * 
+         *
          * @param exception The error that occurred during the transfer, may be {@code null} if none.
          * @return This event builder for chaining, never {@code null}.
          */
-        public Builder setException( Exception exception )
-        {
+        public Builder setException(Exception exception) {
             this.exception = exception;
             return this;
         }
@@ -400,14 +370,11 @@ public final class TransferEvent
         /**
          * Builds a new transfer event from the current values of this builder. The state of the builder itself remains
          * unchanged.
-         * 
+         *
          * @return The transfer event, never {@code null}.
          */
-        public TransferEvent build()
-        {
-            return new TransferEvent( this );
+        public TransferEvent build() {
+            return new TransferEvent(this);
         }
-
     }
-
 }
