@@ -1,5 +1,3 @@
-package org.eclipse.aether;
-
 /*
  * Licensed to the Apache Software Foundation (ASF) under one
  * or more contributor license agreements.  See the NOTICE file
@@ -8,9 +6,9 @@ package org.eclipse.aether;
  * to you under the Apache License, Version 2.0 (the
  * "License"); you may not use this file except in compliance
  * with the License.  You may obtain a copy of the License at
- * 
- *  http://www.apache.org/licenses/LICENSE-2.0
- * 
+ *
+ *   http://www.apache.org/licenses/LICENSE-2.0
+ *
  * Unless required by applicable law or agreed to in writing,
  * software distributed under the License is distributed on an
  * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
@@ -18,27 +16,22 @@ package org.eclipse.aether;
  * specific language governing permissions and limitations
  * under the License.
  */
-
-import static org.junit.Assert.*;
+package org.eclipse.aether;
 
 import java.lang.reflect.Method;
 
 import org.junit.Test;
 
-public class AbstractForwardingRepositorySystemSessionTest
-{
+import static org.junit.Assert.*;
+
+public class AbstractForwardingRepositorySystemSessionTest {
 
     @Test
-    public void testAllMethodsImplemented()
-        throws Exception
-    {
-        for ( Method method : RepositorySystemSession.class.getMethods() )
-        {
-            Method m =
-                AbstractForwardingRepositorySystemSession.class.getDeclaredMethod( method.getName(),
-                                                                                   method.getParameterTypes() );
-            assertNotNull( method.toString(), m );
+    public void testAllMethodsImplemented() throws Exception {
+        for (Method method : RepositorySystemSession.class.getMethods()) {
+            Method m = AbstractForwardingRepositorySystemSession.class.getDeclaredMethod(
+                    method.getName(), method.getParameterTypes());
+            assertNotNull(method.toString(), m);
         }
     }
-
 }
