@@ -1,5 +1,3 @@
-package org.apache.maven.resolver.examples;
-
 /*
  * Licensed to the Apache Software Foundation (ASF) under one
  * or more contributor license agreements.  See the NOTICE file
@@ -8,9 +6,9 @@ package org.apache.maven.resolver.examples;
  * to you under the Apache License, Version 2.0 (the
  * "License"); you may not use this file except in compliance
  * with the License.  You may obtain a copy of the License at
- * 
- *  http://www.apache.org/licenses/LICENSE-2.0
- * 
+ *
+ *   http://www.apache.org/licenses/LICENSE-2.0
+ *
  * Unless required by applicable law or agreed to in writing,
  * software distributed under the License is distributed on an
  * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
@@ -18,6 +16,7 @@ package org.apache.maven.resolver.examples;
  * specific language governing permissions and limitations
  * under the License.
  */
+package org.apache.maven.resolver.examples;
 
 import org.apache.maven.resolver.examples.util.Booter;
 import org.eclipse.aether.RepositorySystem;
@@ -31,36 +30,31 @@ import org.eclipse.aether.resolution.ArtifactDescriptorResult;
 /**
  * Determines the direct dependencies of an artifact as declared in its artifact descriptor (POM).
  */
-public class GetDirectDependencies
-{
+public class GetDirectDependencies {
 
     /**
      * Main.
      * @param args
      * @throws Exception
      */
-    public static void main( String[] args )
-        throws Exception
-    {
-        System.out.println( "------------------------------------------------------------" );
-        System.out.println( GetDirectDependencies.class.getSimpleName() );
+    public static void main(String[] args) throws Exception {
+        System.out.println("------------------------------------------------------------");
+        System.out.println(GetDirectDependencies.class.getSimpleName());
 
-        RepositorySystem system = Booter.newRepositorySystem();
+        RepositorySystem system = Booter.newRepositorySystem(Booter.selectFactory(args));
 
-        RepositorySystemSession session = Booter.newRepositorySystemSession( system );
+        RepositorySystemSession session = Booter.newRepositorySystemSession(system);
 
-        Artifact artifact = new DefaultArtifact( "org.apache.maven.resolver:maven-resolver-impl:1.3.3" );
+        Artifact artifact = new DefaultArtifact("org.apache.maven.resolver:maven-resolver-impl:1.3.3");
 
         ArtifactDescriptorRequest descriptorRequest = new ArtifactDescriptorRequest();
-        descriptorRequest.setArtifact( artifact );
-        descriptorRequest.setRepositories( Booter.newRepositories( system, session ) );
+        descriptorRequest.setArtifact(artifact);
+        descriptorRequest.setRepositories(Booter.newRepositories(system, session));
 
-        ArtifactDescriptorResult descriptorResult = system.readArtifactDescriptor( session, descriptorRequest );
+        ArtifactDescriptorResult descriptorResult = system.readArtifactDescriptor(session, descriptorRequest);
 
-        for ( Dependency dependency : descriptorResult.getDependencies() )
-        {
-            System.out.println( dependency );
+        for (Dependency dependency : descriptorResult.getDependencies()) {
+            System.out.println(dependency);
         }
     }
-
 }
