@@ -1,5 +1,3 @@
-package org.apache.maven.resolver.examples.guice;
-
 /*
  * Licensed to the Apache Software Foundation (ASF) under one
  * or more contributor license agreements.  See the NOTICE file
@@ -8,9 +6,9 @@ package org.apache.maven.resolver.examples.guice;
  * to you under the Apache License, Version 2.0 (the
  * "License"); you may not use this file except in compliance
  * with the License.  You may obtain a copy of the License at
- * 
- *  http://www.apache.org/licenses/LICENSE-2.0
- * 
+ *
+ *   http://www.apache.org/licenses/LICENSE-2.0
+ *
  * Unless required by applicable law or agreed to in writing,
  * software distributed under the License is distributed on an
  * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
@@ -18,20 +16,17 @@ package org.apache.maven.resolver.examples.guice;
  * specific language governing permissions and limitations
  * under the License.
  */
-
-import org.eclipse.aether.RepositorySystem;
+package org.apache.maven.resolver.examples.guice;
 
 import com.google.inject.Guice;
+import org.eclipse.aether.RepositorySystem;
 
 /**
  * A factory for repository system instances that employs JSR-330 via Guice to wire up the system's components.
  */
-public class GuiceRepositorySystemFactory
-{
+public class GuiceRepositorySystemFactory {
 
-    public static RepositorySystem newRepositorySystem()
-    {
-        return Guice.createInjector( new DemoResolverModule() ).getInstance( RepositorySystem.class );
+    public static RepositorySystem newRepositorySystem() {
+        return Guice.createInjector(new DemoResolverModule()).getInstance(RepositorySystem.class);
     }
-
 }
