@@ -1,5 +1,3 @@
-package org.eclipse.aether.impl;
-
 /*
  * Licensed to the Apache Software Foundation (ASF) under one
  * or more contributor license agreements.  See the NOTICE file
@@ -8,9 +6,9 @@ package org.eclipse.aether.impl;
  * to you under the Apache License, Version 2.0 (the
  * "License"); you may not use this file except in compliance
  * with the License.  You may obtain a copy of the License at
- * 
- *  http://www.apache.org/licenses/LICENSE-2.0
- * 
+ *
+ *   http://www.apache.org/licenses/LICENSE-2.0
+ *
  * Unless required by applicable law or agreed to in writing,
  * software distributed under the License is distributed on an
  * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
@@ -18,18 +16,19 @@ package org.eclipse.aether.impl;
  * specific language governing permissions and limitations
  * under the License.
  */
+package org.eclipse.aether.impl;
 
 import org.eclipse.aether.RepositorySystemSession;
 import org.eclipse.aether.resolution.VersionRangeRequest;
 import org.eclipse.aether.resolution.VersionRangeResult;
 
-public class StubVersionRangeResolver
-    implements VersionRangeResolver
-{
+import static java.util.Objects.requireNonNull;
 
-    public VersionRangeResult resolveVersionRange( RepositorySystemSession session, VersionRangeRequest request )
-    {
-        return new VersionRangeResult( request );
+public class StubVersionRangeResolver implements VersionRangeResolver {
+
+    public VersionRangeResult resolveVersionRange(RepositorySystemSession session, VersionRangeRequest request) {
+        requireNonNull(session, "session cannot be null");
+        requireNonNull(request, "request cannot be null");
+        return new VersionRangeResult(request);
     }
-
 }
