@@ -1,5 +1,3 @@
-package org.eclipse.aether.internal.test.util;
-
 /*
  * Licensed to the Apache Software Foundation (ASF) under one
  * or more contributor license agreements.  See the NOTICE file
@@ -8,9 +6,9 @@ package org.eclipse.aether.internal.test.util;
  * to you under the Apache License, Version 2.0 (the
  * "License"); you may not use this file except in compliance
  * with the License.  You may obtain a copy of the License at
- * 
- *  http://www.apache.org/licenses/LICENSE-2.0
- * 
+ *
+ *   http://www.apache.org/licenses/LICENSE-2.0
+ *
  * Unless required by applicable law or agreed to in writing,
  * software distributed under the License is distributed on an
  * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
@@ -18,9 +16,9 @@ package org.eclipse.aether.internal.test.util;
  * specific language governing permissions and limitations
  * under the License.
  */
+package org.eclipse.aether.internal.test.util;
 
-class ArtifactDefinition
-{
+class ArtifactDefinition {
     private String groupId;
 
     private String artifactId;
@@ -39,102 +37,81 @@ class ArtifactDefinition
 
     private Boolean optional;
 
-    ArtifactDefinition( String def )
-    {
+    ArtifactDefinition(String def) {
         this.definition = def.trim();
 
-        if ( definition.startsWith( "(" ) )
-        {
-            int idx = definition.indexOf( ')' );
-            this.id = definition.substring( 1, idx );
-            this.definition = definition.substring( idx + 1 );
-        }
-        else if ( definition.startsWith( "^" ) )
-        {
-            this.reference = definition.substring( 1 );
+        if (definition.startsWith("(")) {
+            int idx = definition.indexOf(')');
+            this.id = definition.substring(1, idx);
+            this.definition = definition.substring(idx + 1);
+        } else if (definition.startsWith("^")) {
+            this.reference = definition.substring(1);
             return;
         }
 
-        String[] split = definition.split( ":" );
-        if ( split.length < 4 )
-        {
-            throw new IllegalArgumentException( "Need definition like 'gid:aid:ext:ver[:scope]', but was: "
-                + definition );
+        String[] split = definition.split(":");
+        if (split.length < 4) {
+            throw new IllegalArgumentException(
+                    "Need definition like 'gid:aid:ext:ver[:scope]', but was: " + definition);
         }
         groupId = split[0];
         artifactId = split[1];
         extension = split[2];
         version = split[3];
-        if ( split.length > 4 )
-        {
+        if (split.length > 4) {
             scope = split[4];
         }
-        if ( split.length > 5 )
-        {
-            if ( "optional".equalsIgnoreCase( split[5] ) )
-            {
+        if (split.length > 5) {
+            if ("optional".equalsIgnoreCase(split[5])) {
                 optional = true;
-            }
-            else if ( "!optional".equalsIgnoreCase( split[5] ) )
-            {
+            } else if ("!optional".equalsIgnoreCase(split[5])) {
                 optional = false;
             }
         }
     }
 
-    public String getGroupId()
-    {
+    public String getGroupId() {
         return groupId;
     }
 
-    public String getArtifactId()
-    {
+    public String getArtifactId() {
         return artifactId;
     }
 
-    public String getExtension()
-    {
+    public String getExtension() {
         return extension;
     }
 
-    public String getVersion()
-    {
+    public String getVersion() {
         return version;
     }
 
-    public String getScope()
-    {
+    public String getScope() {
         return scope;
     }
 
     @Override
-    public String toString()
-    {
+    public String toString() {
         return definition;
     }
 
-    public String getId()
-    {
+    public String getId() {
         return id;
     }
 
-    public String getReference()
-    {
+    public String getReference() {
         return reference;
     }
 
-    public boolean isReference()
-    {
+    public boolean isReference() {
         return reference != null;
     }
 
-    public boolean hasId()
-    {
+    public boolean hasId() {
         return id != null;
     }
 
-    public Boolean getOptional()
-    {
+    public Boolean getOptional() {
         return optional;
     }
 }
