@@ -1,5 +1,3 @@
-package org.eclipse.aether.transport.file;
-
 /*
  * Licensed to the Apache Software Foundation (ASF) under one
  * or more contributor license agreements.  See the NOTICE file
@@ -8,9 +6,9 @@ package org.eclipse.aether.transport.file;
  * to you under the Apache License, Version 2.0 (the
  * "License"); you may not use this file except in compliance
  * with the License.  You may obtain a copy of the License at
- * 
- *  http://www.apache.org/licenses/LICENSE-2.0
- * 
+ *
+ *   http://www.apache.org/licenses/LICENSE-2.0
+ *
  * Unless required by applicable law or agreed to in writing,
  * software distributed under the License is distributed on an
  * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
@@ -18,6 +16,7 @@ package org.eclipse.aether.transport.file;
  * specific language governing permissions and limitations
  * under the License.
  */
+package org.eclipse.aether.transport.file;
 
 import javax.inject.Named;
 
@@ -27,13 +26,14 @@ import org.eclipse.aether.spi.connector.transport.Transporter;
 import org.eclipse.aether.spi.connector.transport.TransporterFactory;
 import org.eclipse.aether.transfer.NoTransporterException;
 
+import static java.util.Objects.requireNonNull;
+
 /**
  * A transporter factory for repositories using the {@code file:} protocol.
  */
-@Named( "file" )
-public final class FileTransporterFactory
-    implements TransporterFactory
-{
+@Named(FileTransporterFactory.NAME)
+public final class FileTransporterFactory implements TransporterFactory {
+    public static final String NAME = "file";
 
     private float priority;
 
@@ -42,32 +42,30 @@ public final class FileTransporterFactory
      * by clients, the new factory needs to be configured via its various mutators before first use or runtime errors
      * will occur.
      */
-    public FileTransporterFactory()
-    {
+    public FileTransporterFactory() {
         // enables default constructor
     }
 
-    public float getPriority()
-    {
+    public float getPriority() {
         return priority;
     }
 
     /**
      * Sets the priority of this component.
-     * 
+     *
      * @param priority The priority.
      * @return This component for chaining, never {@code null}.
      */
-    public FileTransporterFactory setPriority( float priority )
-    {
+    public FileTransporterFactory setPriority(float priority) {
         this.priority = priority;
         return this;
     }
 
-    public Transporter newInstance( RepositorySystemSession session, RemoteRepository repository )
-        throws NoTransporterException
-    {
-        return new FileTransporter( repository );
-    }
+    public Transporter newInstance(RepositorySystemSession session, RemoteRepository repository)
+            throws NoTransporterException {
+        requireNonNull(session, "session cannot be null");
+        requireNonNull(repository, "repository cannot be null");
 
+        return new FileTransporter(repository);
+    }
 }
