@@ -1,5 +1,3 @@
-package org.eclipse.aether.util;
-
 /*
  * Licensed to the Apache Software Foundation (ASF) under one
  * or more contributor license agreements.  See the NOTICE file
@@ -8,9 +6,9 @@ package org.eclipse.aether.util;
  * to you under the Apache License, Version 2.0 (the
  * "License"); you may not use this file except in compliance
  * with the License.  You may obtain a copy of the License at
- * 
- *  http://www.apache.org/licenses/LICENSE-2.0
- * 
+ *
+ *   http://www.apache.org/licenses/LICENSE-2.0
+ *
  * Unless required by applicable law or agreed to in writing,
  * software distributed under the License is distributed on an
  * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
@@ -18,23 +16,20 @@ package org.eclipse.aether.util;
  * specific language governing permissions and limitations
  * under the License.
  */
+package org.eclipse.aether.util;
+
+import org.junit.Test;
 
 import static org.junit.Assert.*;
 
-import org.eclipse.aether.util.StringUtils;
-import org.junit.Test;
-
-@SuppressWarnings( "deprecation" )
-public class StringUtilsTest
-{
+@SuppressWarnings("deprecation")
+public class StringUtilsTest {
 
     @Test
-    public void testIsEmpty()
-    {
-        assertTrue( StringUtils.isEmpty( null ) );
-        assertTrue( StringUtils.isEmpty( "" ) );
-        assertFalse( StringUtils.isEmpty( " " ) );
-        assertFalse( StringUtils.isEmpty( "test" ) );
+    public void testIsEmpty() {
+        assertTrue(StringUtils.isEmpty(null));
+        assertTrue(StringUtils.isEmpty(""));
+        assertFalse(StringUtils.isEmpty(" "));
+        assertFalse(StringUtils.isEmpty("test"));
     }
-
 }
