@@ -1,5 +1,3 @@
-package org.eclipse.aether.util.graph.selector;
-
 /*
  * Licensed to the Apache Software Foundation (ASF) under one
  * or more contributor license agreements.  See the NOTICE file
@@ -9,7 +7,7 @@ package org.eclipse.aether.util.graph.selector;
  * "License"); you may not use this file except in compliance
  * with the License.  You may obtain a copy of the License at
  *
- *  http://www.apache.org/licenses/LICENSE-2.0
+ *   http://www.apache.org/licenses/LICENSE-2.0
  *
  * Unless required by applicable law or agreed to in writing,
  * software distributed under the License is distributed on an
@@ -18,21 +16,19 @@ package org.eclipse.aether.util.graph.selector;
  * specific language governing permissions and limitations
  * under the License.
  */
-
-import static org.junit.Assert.*;
-
-import org.junit.Test;
+package org.eclipse.aether.util.graph.selector;
 
 import java.util.Collections;
 
-public class ScopeDependencySelectorTest
-{
+import org.junit.Test;
+
+import static org.junit.Assert.*;
+
+public class ScopeDependencySelectorTest {
     @Test
-    public void testToString()
-    {
+    public void testToString() {
         assertEquals(
-            "ScopeDependencySelector(included: [foo], excluded: [bar], transitive: false)",
-            new ScopeDependencySelector(Collections.singleton( "foo" ), Collections.singleton( "bar" ) ).toString()
-        );
+                "ScopeDependencySelector(included: [foo], excluded: [bar], transitive: false)",
+                new ScopeDependencySelector(Collections.singleton("foo"), Collections.singleton("bar")).toString());
     }
-}
\ No newline at end of file
+}
